==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_RE","Odgovor");
define("_SUBJECT","Naslov");
define("_PRIVATEMESSAGES","Vaa zasebna sporoila");
define("_CHECKALL","Preveri vse");
define("_FROM","Od");
define("_DATE","Datum");
define("_DONTHAVEMESSAGES","Nimate sporoil");
define("_NOTREAD","Neprebranih");
define("_MSGSTATUS","Status sporoila");
define("_PRIVATEMESSAGE","Zasebno sporoilo");
define("_INDEX","Kazalo");
define("_SENT","Poslano");
define("_PREVIOUSMESSAGE","Prejnje sporoilo");
define("_NEXTMESSAGE","Naslednje sporoilo");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","O poiljanju");
define("_ALLREGCANPOST","Vsi <a href=\"modules.php?name=Your_Account\">lani</a> lahko poiljajo zasebna sporoila");
define("_TO","Prejemnik");
define("_MESSAGEICON","Ikona sporoila");
define("_MESSAGE","Sporoilo");
define("_HTML","HTML");
define("_PMON","Vkljuen");
define("_PMOFF","Izkljuen");
define("_BBCODE","BBCode");
define("_WROTE","je napisal");
define("_OPTIONS","Opcije");
define("_HTMLDISSABLE","Izkljui HTML v tem sporoilu");
define("_BBCODEDISSABLE","Izkljui <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> v tem sporoilu");
define("_SMILEDISSABLE","Izkljui <a href=\"bb_smilies.php\" target=\"_blank\"><i>smekote</i></a> v tem sporoilu");
define("_CANCELREPLY","Preklii odgovor");
define("_CANCELSEND","Preklii poiljanje");
define("_CLEAR","Poisti");
define("_SUBMIT","Polji");
define("_USERNOTINDB","Navedeni lan ne obstaja v bazi podatkov.");
define("_CHECKNAMEANDTRY","Preverite ime in poizkusite ponovno.");
define("_MSGPOSTED","Vae sporoilo je poslano.");
define("_RETURNTOPMSG","Tukaj lahko kliknete za ponovno branje vaih zasebnih sporoil.");
define("_MSGDELETED","Vaa sporoila so bila izbrisana.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_RE","Odgovor");
define("_SUBJECT","Naslov");
define("_PRIVATEMESSAGES","Vaa zasebna sporoila");
define("_CHECKALL","Preveri vse");
define("_FROM","Od");
define("_DATE","Datum");
define("_DONTHAVEMESSAGES","Nimate sporoil");
define("_NOTREAD","Neprebranih");
define("_MSGSTATUS","Status sporoila");
define("_PRIVATEMESSAGE","Zasebno sporoilo");
define("_INDEX","Kazalo");
define("_SENT","Poslano");
define("_PREVIOUSMESSAGE","Prejnje sporoilo");
define("_NEXTMESSAGE","Naslednje sporoilo");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","O poiljanju");
define("_ALLREGCANPOST","Vsi <a href=\"modules.php?name=Your_Account\">lani</a> lahko poiljajo zasebna sporoila");
define("_TO","Prejemnik");
define("_MESSAGEICON","Ikona sporoila");
define("_MESSAGE","Sporoilo");
define("_HTML","HTML");
define("_PMON","Vkljuen");
define("_PMOFF","Izkljuen");
define("_BBCODE","BBCode");
define("_WROTE","je napisal");
define("_OPTIONS","Opcije");
define("_HTMLDISSABLE","Izkljui HTML v tem sporoilu");
define("_BBCODEDISSABLE","Izkljui <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> v tem sporoilu");
define("_SMILEDISSABLE","Izkljui <a href=\"bb_smilies.php\" target=\"_blank\"><i>smekote</i></a> v tem sporoilu");
define("_CANCELREPLY","Preklii odgovor");
define("_CANCELSEND","Preklii poiljanje");
define("_CLEAR","Poisti");
define("_SUBMIT","Polji");
define("_USERNOTINDB","Navedeni lan ne obstaja v bazi podatkov.");
define("_CHECKNAMEANDTRY","Preverite ime in poizkusite ponovno.");
define("_MSGPOSTED","Vae sporoilo je poslano.");
define("_RETURNTOPMSG","Tukaj lahko kliknete za ponovno branje vaih zasebnih sporoil.");
define("_MSGDELETED","Vaa sporoila so bila izbrisana.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
